/** Extra properties that are not present in the default PaletteOptions of mui. For autocompletion */
export interface ExtraColorsForMui5 {
  /** Colors that can be used for data visualisation, e.g. nodes, edges */
  dataPointColors: string[];

  nodes: Array<string>;
  nodesBase: [string];
  elements: {
    entityBase: [string, string, string]; // normal, lighter, darker
    entitySecond: [string];
    relation: [string, string, string];
    relationBase: [string, string, string];
    relationSecond: [string];
    attribute: [string, string, string];
    function: [string, string, string];
  };
  visEdge: string;
  nodeHighlightedEdge: string;
  background: string;
  visBackground: string;
  attr: string;
  entry: string;
  relation: string;
  graphEdge: string;
  builderEdge: string;
  text: string;
  menuText: string;
  elementText: string;
  dragger: string;
  logo: string;

  queryBuilder: {
    text: string;
    entity: {
      background: string;
      lighterbg?: string;
    };
    relation: {
      background: string;
      lighterbg?: string;
    };
    attribute: {
      background: string;
      lighterbg?: string;
    };
  };
}

export interface ColorPalette {
  // Custom colors
  custom: ExtraColorsForMui5;
  // MUI colors
  primary: {
    light?: string;
    main: string;
    dark?: string;
  };
  secondary: {
    light?: string;
    main: string;
    dark?: string;
  };
}

/** Our custom color palette config. With the palette options from MUI that we are going to use. */
export interface ColorPaletteConfig {
  lightPalette: ColorPalette;
  darkPalette: ColorPalette;
  darkMode: boolean;
}

const defaultPallete: ColorPalette = {
  custom: {
    dataPointColors: ['#ff0000', '#00ff00', '#0000ff'],
    nodes: [
      '#181520', // black
      '#d49350', // orange
      '#1e9797', // blue
      '#d56a50', // red
      '#800000',
      '#fabed4',
      '#808000',
      '#ffe119',
      '#bfef45',
      '#3cb44b',
      '#42d4f4',
      '#000075',
      '#4363d8',
      '#911eb4',
      '#dcbeff',
      '#f032e6',
      '#a9a9a9',
      '#2d7c0b',
      '#00ff00',
      '#0000ff',
    ],
    nodesBase: ['#e9e9e9'],
    elements: {
      entityBase: ['#ffac57', '#ECB880', '#a36a30'], // normal, lighter, darker
      relation: ['#1FA2A2', '#82d9d9', '#166262'],
      entitySecond: ['#ff9727'],
      relationBase: ['#3bc4ff', '#82d9d9', '#166262'],
      relationSecond: ['#02aaf2'],
      attribute: ['#bfb6af', '#f8f2ee', '#e2d9d3'],
      function: ['#8c75c9', '#ECB880', '#a36a30'],
    },
    visEdge: '#999999',
    nodeHighlightedEdge: '#30A530',
    background: '#fffdfa',
    visBackground: '#ffffff',
    attr: '#e2d9d3',
    entry: '#d49350',
    relation: '#1e9797',
    graphEdge: '#181520',
    builderEdge: '#000000',
    text: '#000000',
    menuText: '#000000',
    elementText: '#000000',
    dragger: '#dddddd',
    logo: 'black',
    queryBuilder: {
      text: 'black',
      entity: {
        background: '#FC4F4F',
      },
      relation: {
        background: '#FF9F45',
      },
      attribute: {
        background: '#C7C7C7',
      },
    },
  },
  // If light and dark are not set, these will be calculated using main.
  // light/dark have nothing with darkmode, these are just a light and dark variation
  primary: {
    // light: '#42a5f5',
    main: '#1976d2',
    // dark: '#1565c0',
  },
  secondary: {
    // light: '#ba68c8',
    main: '#9c27b0',
    // dark: '#7b1fa2',
  },
};

// This looks very much like the mui Palette interface,
// But we don't reference that type directly here to stay decoupled
export const initialState: ColorPaletteConfig = {
  lightPalette: defaultPallete,
  darkPalette: {
    ...defaultPallete,
    custom: {
      ...defaultPallete.custom,
      nodes: ['#eaeaea', '#5358ed', '#4eedba', '#b665ed', '#bd73ef', '#c380f0', '#c88cf1'],
      nodesBase: ['#e9e9e9'],
      elements: {
        entityBase: ['#ffac57', '#ECB880', '#a36a30'], // normal, lighter, darker
        entitySecond: ['#ff9727'],
        relationBase: ['#3bc4ff', '#82d9d9', '#166262'],
        relationSecond: ['#02aaf2'],
        relation: ['#4eedba', '#DBF9EF', '#36A580'],
        attribute: ['#D7D7D7', '#f8f2ee', '#e2d9d3'],
        function: ['#B665ED', '#CDA4EA', '#8048A8'],
      },
      visEdge: '#999999',
      nodeHighlightedEdge: '#30A530',
      background: '#171721',
      visBackground: '#292935',
      attr: '#e2d9d3',
      graphEdge: '#eaeaea',
      builderEdge: '#ffffff',
      text: '#ff00ff',
      menuText: '#ffffff',
      elementText: '#000000',
      dragger: '#171721',
      logo: 'white',
    },
    primary: {
      main: '#e3f3fd',
    },
    secondary: {
      main: '#f3e5f5',
    },
  },
  darkMode: false,
};
