import { PropsWithChildren, useEffect, useRef } from 'react';
import { Dialog, DialogProps } from '../../components/Dialog';
import React from 'react';
import CloseIcon from '@mui/icons-material/Close';
import { useAppDispatch, useSchemaSettings } from '../../data-access';
import { SchemaSettings, setSchemaSettings } from '../../data-access/store/schemaSlice';

export const SchemaDialog = React.forwardRef<HTMLDivElement, DialogProps>((props, ref) => {
  const settings = useSchemaSettings();
  const dispatch = useAppDispatch();
  const [state, setState] = React.useState<SchemaSettings>(settings);

  useEffect(() => {
    setState(settings);
  }, [settings, props.open]);

  function submit() {
    dispatch(setSchemaSettings(state));

    props.onClose();
  }

  return (
    <>
      {props.open && (
        <div className="absolute  opacity-100 transition-opacity group-hover:opacity-100 z-50 " ref={ref}>
          <div className="card absolute card-bordered bg-white rounded-none">
            <form
              className="card-body px-0 w-72 py-5"
              onSubmit={(e) => {
                e.preventDefault();
                submit();
              }}
            >
              <div className="card-title p-5 py-0 flex w-full">
                <h2 className="w-full">Quick Settings</h2>
                <button className="btn btn-circle btn-sm btn-ghost" onClick={() => props.onClose()}>
                  <CloseIcon fontSize="small" />
                </button>
              </div>
              <div className="divider m-0"></div>
              <div className="form-control px-5">
                <label className="label cursor-pointer w-fit gap-2 px-0 py-1">
                  <input type="checkbox" checked={true} onChange={(e) => {}} className="checkbox checkbox-xs" />
                  <span className="label-text">Points</span>
                </label>
                <label className="label cursor-pointer w-fit gap-2 px-0 py-1">
                  <input type="checkbox" checked={true} onChange={(e) => {}} className="checkbox checkbox-xs" />
                  <span className="label-text">Line</span>
                </label>
                <label className="label cursor-pointer w-fit gap-2 px-0 py-1">
                  <input type="checkbox" checked={true} onChange={(e) => {}} className="checkbox checkbox-xs" />
                  <span className="label-text">Line</span>
                </label>
              </div>
              <div className="divider m-0"></div>
              <div className="form-control px-5">
                <label className="label">
                  <span className="label-text">Opacity</span>
                </label>
                <input type="range" min={0} max="100" value="40" onChange={(e) => {}} className="range range-sm" />
              </div>
              <div className="divider m-0"></div>
              <div className="form-control px-5">
                <label className="label">
                  <span className="label-text">Histogram</span>
                </label>
                ...
              </div>
              <div className="divider m-0"></div>
              <div className="form-control px-5">
                <label className="label">
                  <span className="label-text">Type of Connection</span>
                </label>
                <select
                  className="select select-primary select-sm "
                  value={state.connectionType}
                  onChange={(e) => {
                    setState({ ...state, connectionType: e.target.value as any });
                  }}
                >
                  <option className="option" value="connection">
                    Default
                  </option>
                  <option className="option" value="step">
                    Step
                  </option>
                  <option className="option" value="straight">
                    Straight
                  </option>
                  <option className="option" value="bezier">
                    Bezier
                  </option>
                </select>
              </div>
              <div className="divider m-0"></div>

              <div className="card-actions mt-1 w-full px-5 flex flex-row">
                <button
                  className="btn btn-secondary flex-grow"
                  onClick={(e) => {
                    e.preventDefault();
                    props.onClose();
                  }}
                >
                  Cancel
                </button>
                <button className="btn btn-primary flex-grow">Apply</button>
              </div>
            </form>
          </div>
        </div>
      )}
    </>
  );
});
