/**
 * This program has been developed by students from the bachelor Computer Science at
 * Utrecht University within the Software Project course.
 * © Copyright Utrecht University (Department of Information and Computing Sciences)
 */

/* istanbul ignore file */
/* The comment above was added so the code coverage wouldn't count this file towards code coverage.
 * We do not test components/renderfunctions/styling files.
 * See testing plan for more details.*/
import React, { useState } from 'react';
import { Node, Handle, Position, NodeProps } from 'reactflow';
import styles from './relation.module.scss';
import { SchemaReactflowRelation, SchemaReactflowRelationWithFunctions } from '../../../model/reactflow';
import { QueryElementTypes } from '@graphpolaris/shared/lib/querybuilder';

/**
 * Relation node component that renders a relation node for the schema.
 * Can be dragged and dropped to the query builder.
 * @param {NodeProps} param0 The data of an entity flow element.
 */
export const RelationNode = React.memo(({ id, data }: NodeProps<SchemaReactflowRelationWithFunctions>) => {
  const [hidden, setHidden] = useState<boolean>(true);

  /**
   * Adds drag functionality in order to be able to drag the relationNode to the schema.
   * @param event React Mouse drag event.
   */
  const onDragStart = (event: React.DragEvent<HTMLDivElement>) => {
    console.log('dragging relation', id, data);
    event.dataTransfer.setData(
      'application/reactflow',
      JSON.stringify({
        type: QueryElementTypes.Relation,
        name: id, //TODO id?
        from: data.from,
        to: data.to,
        collection: data.collection,
        label: data.label,
      })
    );
    event.dataTransfer.effectAllowed = 'move';
  };

  /**
   * Displays the NodeQualityPopup when clicked, and hides them when clicked again
   */
  const onClickToggleNodeQualityPopup = (): void => {
    data.toggleNodeQualityPopup(data.collection);
  };

  /**
   * displays the attribute analytics popup menu when clicked, and hides them when clicked again
   */
  const onClickToggleAttributeAnalyticsPopupMenu = (): void => {
    data.toggleAttributeAnalyticsPopupMenu(data.collection);
  };

  return (
    <div
      onDragStart={(event) => onDragStart(event)}
      onDragStartCapture={(event) => onDragStart(event)}
      onMouseDownCapture={(event) => {
        if (!event.shiftKey) event.stopPropagation();
      }}
      draggable
      // style={{ width: 100, height: 100 }}
    >
      <div className="text-[0.8rem] border-l-2 bg-offwhite-200 border-l-relation-600 min-w-[8rem]">
        <Handle
          style={{ pointerEvents: 'none' }}
          className={styles.handleTriangleTop}
          id="entitySourceLeft"
          position={Position.Top}
          type="target"
        ></Handle>
        {/* <div
          className={styles.relationNodeAttributesBox}
          onClick={() => onClickToggleAttributeAnalyticsPopupMenu()}
          style={{
            width: widthExternalBoxes + 'px',
            backgroundImage: `linear-gradient(-90deg, 
              ${theme.palette.custom.nodesBase} 0%, 
              ${theme.palette.custom.nodesBase} ${calculateAttributeQuality(data)}%, 
              ${theme.palette.custom.elements.relationSecond[0]} ${calculateAttributeQuality(data)}%)`,
          }}
        >
          <span
            style={{
              paddingLeft: '25px',
              float: 'left',
            }}
          >
            A
          </span>
          <span className={styles.nodeSpan}>{data.attributes.length}</span>
        </div> */}
        {/* <div
          className={styles.relationNodeNodesBox}
          onClick={() => onClickToggleNodeQualityPopup()}
          style={{
            width: widthExternalBoxes + 'px',
            backgroundImage: `linear-gradient(-90deg, 
              ${theme.palette.custom.nodesBase} 0%, 
              ${theme.palette.custom.nodesBase} ${calculateRelationQuality(data)}%, 
              ${theme.palette.custom.elements.relationSecond[0]} ${calculateRelationQuality(data)}%)`,
          }}
        >
          <span
            style={{
              paddingLeft: '25px',
              float: 'left',
            }}
          >
            N
          </span>
          <span className={styles.nodeSpan}>{data.nodeCount}</span>
        </div> */}

        <div className="p-2 py-1">
          <span className="">{data.collection}</span>
        </div>

        <Handle className={styles.handleTriangleBottom} style={{ pointerEvents: 'none' }} position={Position.Bottom} type="source"></Handle>
      </div>
    </div>
  );
});

RelationNode.displayName = 'RelationNode';
